==> activity-center-api-3.1.32-sources.jar: cn/com/duiba/activity/center/api/dto/happy_code/HappyCodeOptionDto.java <==
package cn.com.duiba.activity.center.api.dto.happy_code;

import cn.com.duiba.activity.center.api.dto.BaseDto;

import java.util.Date;

/**
 * 开心码奖项
 * Created by hww on 2017/11/6
 */
public class HappyCodeOptionDto extends BaseDto{

    private static final long serialVersionUID = -8712692000538014699L;
    /** 主键id */
    private Long id;
    /** 期次id */
    private Long phaseId;
    /** 奖项标题 */
    private String prizeName;
    /** 奖项类型 */
    private String prizeType;
    /** 奖项图标 */
    private String logo;
    /** 奖项描述 */
    private String description;
    /** 奖项备注 */
    private String memo;
    /** 奖项发放数量 */
    private Integer remaining;
    /** 奖项商品id */
    private Long itemId;
    /** 奖项商品名称 */
    private String itemName;
    /** 删除 */
    private Integer deleted;
    /** 创建时间 */
    private Date gmtCreate;
    /** 更新时间 */
    private Date gmtModified;
    /** 奖项等级（扑克牌模式专用）*/
    private Integer prizeLevel;
    /** 库存id*/
    private Long stockId;

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getPhaseId() {
        return phaseId;
    }

    public void setPhaseId(Long phaseId) {
        this.phaseId = phaseId;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Integer getRemaining() {
        return remaining;
    }

    public void setRemaining(Integer remaining) {
        this.remaining = remaining;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getPrizeLevel() {
        return prizeLevel;
    }

    public void setPrizeLevel(Integer prizeLevel) {
        this.prizeLevel = prizeLevel;
    }
}

==> activity-center-api-3.6.26-20250907.040043-5-sources.jar: cn/com/duiba/activity/center/api/dto/happy_code/HappyCodeOptionDto.java <==
package cn.com.duiba.activity.center.api.dto.happy_code;

import cn.com.duiba.activity.center.api.dto.BaseDto;

import java.util.Date;
import java.util.Objects;

/**
 * 开心码奖项
 * Created by hww on 2017/11/6
 */
public class HappyCodeOptionDto extends BaseDto{

    private static final long serialVersionUID = -8712692000538014699L;
    /** 主键id */
    private Long id;
    /** 期次id */
    private Long phaseId;
    /** 奖项标题 */
    private String prizeName;
    /** 奖项类型 */
    private String prizeType;
    /** 奖项图标 */
    private String logo;
    /** 奖项描述 */
    private String description;
    /** 奖项备注 */
    private String memo;
    /** 奖项发放数量 */
    private Integer remaining;
    /** 奖项商品id */
    private Long itemId;
    /** 奖项商品名称 */
    private String itemName;
    /** 删除 */
    private Integer deleted;
    /** 创建时间 */
    private Date gmtCreate;
    /** 更新时间 */
    private Date gmtModified;
    /** 奖项等级（扑克牌模式专用）*/
    private Integer prizeLevel;
    /** 库存id*/
    private Long stockId;
    /**
     * 奖品价值
     */
    private Integer facePrice;
    /**
     * 奖品概率
     */
    private Integer rate;
    /**
     * 保底人数
     */
    private Integer minComein;

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getPhaseId() {
        return phaseId;
    }

    public void setPhaseId(Long phaseId) {
        this.phaseId = phaseId;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Integer getRemaining() {
        return remaining;
    }

    public void setRemaining(Integer remaining) {
        this.remaining = remaining;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getPrizeLevel() {
        return prizeLevel;
    }

    public void setPrizeLevel(Integer prizeLevel) {
        this.prizeLevel = prizeLevel;
    }

    public Integer getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Integer facePrice) {
        this.facePrice = facePrice;
    }

    public Integer getRate() {
        return rate;
    }

    public void setRate(Integer rate) {
        this.rate = rate;
    }

    public Integer getMinComein() {
        return minComein;
    }

    public void setMinComein(Integer minComein) {
        this.minComein = minComein;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        if (!super.equals(o)) {
            return false;
        }
        HappyCodeOptionDto that = (HappyCodeOptionDto) o;
        return Objects.equals(id, that.id);
    }

    @Override
    public int hashCode() {
        return Objects.hash(super.hashCode(), id);
    }
}
